.. pareidolia documentation master file, created by
   sphinx-quickstart on Fri Jul  2 14:28:40 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pareidolia's documentation!
======================================
Pareidolia is a command line tool and python package for the analysis of chromosome contact maps. It uses `Chromosight's <https://github.com/koszullab/chromosight>`_ convolution algorithm to detect specific patterns such as chromatin loops and domain borders, and quantify changes in their intensity between two conditions. You can follow Pareidolia's development on `Github <https://github.com/koszullab/pareidolia>`_ .

.. toctree::
   :maxdepth: 2
   :caption: Contents:

Tutorial
========
.. toctree::
    :maxdepth: 3

    TUTORIAL

Reference API
=============

.. toctree::
    :maxdepth: 2

    api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
